@@ -3,9 +3,9 @@
   <head>  
     <meta charset="utf-8">  
     <title>Read later - ownCloud</title>  
-    <link rel="stylesheet" href="css/readlater.css">  
   </head>
   <body>
   	<div class="message"><h1>Saved!</h1></div>
+		<a href="javascript:self.close()" >Close the window</a>
   </body>  
 </html>  
\ No newline at end of file
