@@ -6,27 +6,22 @@
  * See the COPYING-README file.
  */
 
- 
+
 OCP\JSON::checkLoggedIn();
 OCP\JSON::checkAppEnabled('calendar');
+OCP\JSON::callCheck();
 
 $id = $_POST['id'];
 
-if(!array_key_exists('calendar', $_POST)){
+if(!array_key_exists('calendar', $_POST)) {
 	$cal = OC_Calendar_Object::getCalendarid($id);
 	$_POST['calendar'] = $cal;
 }else{
 	$cal = $_POST['calendar'];
 }
 
-$access = OC_Calendar_App::getaccess($id, OC_Calendar_App::EVENT);
-if($access != 'owner' && $access != 'rw'){
-	OCP\JSON::error(array('message'=>'permission denied'));
-	exit;
-}
-
 $errarr = OC_Calendar_Object::validateRequest($_POST);
-if($errarr){
+if($errarr) {
 	//show validate errors
 	OCP\JSON::error($errarr);
 	exit;
@@ -37,9 +32,19 @@ if($errarr){
 	OC_Calendar_App::isNotModified($vcalendar->VEVENT, $_POST['lastmodified']);
 	OC_Calendar_Object::updateVCalendarFromRequest($_POST, $vcalendar);
 
-	OC_Calendar_Object::edit($id, $vcalendar->serialize());
+	try {
+		OC_Calendar_Object::edit($id, $vcalendar->serialize());
+	} catch(Exception $e) {
+		OCP\JSON::error(array('data' => array('message'=>$e->getMessage())));
+		exit;
+	}
 	if ($data['calendarid'] != $cal) {
-		OC_Calendar_Object::moveToCalendar($id, $cal);
+		try {
+			OC_Calendar_Object::moveToCalendar($id, $cal);
+		} catch(Exception $e) {
+			OCP\JSON::error(array('data' => array('message'=>$e->getMessage())));
+			exit;
+		}
 	}
 	OCP\JSON::success();
 }
\ No newline at end of file
