@@ -1,7 +1,17 @@
 <?php $TRANSLATIONS = array(
+"Wrong calendar" => "Kalender salah",
 "Timezone changed" => "Zona waktu telah diubah",
 "Invalid request" => "Permintaan tidak sah",
 "Calendar" => "Kalender",
+"Birthday" => "Ulang tahun",
+"Business" => "Usaha",
+"Clients" => "Klien",
+"Deliverer" => "Pengirim",
+"Holidays" => "Hari libur",
+"Journey" => "Perjalanan",
+"Meeting" => "Rapat",
+"Other" => "Lainnya",
+"Questions" => "Pertanyaan",
 "Does not repeat" => "Tidak akan mengulangi",
 "Daily" => "Harian",
 "Weekly" => "Mingguan",
@@ -14,9 +24,6 @@
 "Week" => "Minggu",
 "Month" => "Bulan",
 "Today" => "Hari ini",
-"Calendars" => "Kalender",
-"There was a fail, while parsing the file." => "Terjadi kesalahan, saat mengurai berkas.",
-"Choose active calendars" => "Pilih kalender aktif",
 "Download" => "Unduh",
 "Edit" => "Sunting",
 "Edit calendar" => "Sunting kalender",
