@@ -1,11 +1,9 @@
 <?php $TRANSLATIONS = array(
 "Information about vCard is incorrect. Please reload the page." => "Podaci o vKarti su neispravni. Ponovo učitajte stranicu.",
+"Edit" => "Uredi",
+"Delete" => "Obriši",
 "This is not your addressbook." => "Ovo nije vaš adresar.",
 "Contact could not be found." => "Kontakt se ne može naći.",
-"Address" => "Adresa",
-"Telephone" => "Telefon",
-"Email" => "E-mail",
-"Organization" => "Organizacija",
 "Work" => "Posao",
 "Home" => "Kuća",
 "Mobile" => "Mobilni",
@@ -14,14 +12,14 @@
 "Fax" => "Faks",
 "Video" => "Video",
 "Pager" => "Pejdžer",
-"Add Contact" => "Dodaj kontakt",
-"Edit" => "Uredi",
-"Delete" => "Obriši",
 "Birthday" => "Rođendan",
+"Add Contact" => "Dodaj kontakt",
+"Organization" => "Organizacija",
 "Phone" => "Telefon",
+"Email" => "E-mail",
+"Address" => "Adresa",
 "PO Box" => "Poštanski broj",
 "Extended" => "Proširi",
-"Street" => "Ulica",
 "City" => "Grad",
 "Region" => "Regija",
 "Zipcode" => "Zip kod",
