@@ -4,6 +4,7 @@
 
 
 OCP\JSON::checkLoggedIn();
+OCP\JSON::callCheck();
 
 // Get data
 $dir = stripslashes($_GET["dir"]);
@@ -11,11 +12,9 @@ $file = stripslashes($_GET["file"]);
 $newname = stripslashes($_GET["newname"]);
 
 // Delete
-if( OC_Files::move( $dir, $file, $dir, $newname )) {
+if( $newname !== '.' and OC_Files::move( $dir, $file, $dir, $newname )) {
 	OCP\JSON::success(array("data" => array( "dir" => $dir, "file" => $file, "newname" => $newname )));
+} else {
+	$l=OC_L10N::get('files');
+	OCP\JSON::error(array("data" => array( "message" => $l->t("Unable to rename file"))));
 }
-else{
-	OCP\JSON::error(array("data" => array( "message" => "Unable to rename file" )));
-}
-
-?>
