@@ -25,8 +25,32 @@ Files={
 			delete uploadingFiles[index];
 		});
 		procesSelection();
+	},
+	isFileNameValid:function (name) {
+		if (name === '.') {
+			$('#notification').text(t('files', '\'.\' is an invalid file name.'));
+			$('#notification').fadeIn();
+			return false;
+		}
+		if (name.length == 0) {
+			$('#notification').text(t('files', 'File name cannot be empty.'));
+			$('#notification').fadeIn();
+			return false;
+		}
+
+		// check for invalid characters
+		var invalid_characters = ['\\', '/', '<', '>', ':', '"', '|', '?', '*'];
+		for (var i = 0; i < invalid_characters.length; i++) {
+			if (name.indexOf(invalid_characters[i]) != -1) {
+				$('#notification').text(t('files', "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed."));
+				$('#notification').fadeIn();
+				return false;
+			}
+		}
+		$('#notification').fadeOut();
+		return true;
 	}
-}
+};
 $(document).ready(function() {
 	$('#fileList tr').each(function(){
 		//little hack to set unescape filenames in attribute
@@ -40,8 +64,16 @@ $(document).ready(function() {
 	$('#file_action_panel').attr('activeAction', false);
 
 	//drag/drop of files
-	$('#fileList tr[data-write="true"] td.filename').draggable(dragOptions);
-	$('#fileList tr[data-type="dir"][data-write="true"] td.filename').droppable(folderDropOptions);
+	$('#fileList tr td.filename').each(function(i,e){
+		if ($(e).parent().data('permissions') & OC.PERMISSION_DELETE) {
+			$(e).draggable(dragOptions);
+		}
+	});
+	$('#fileList tr[data-type="dir"] td.filename').each(function(i,e){
+		if ($(e).parent().data('permissions') & OC.PERMISSION_CREATE){
+			$(e).droppable(folderDropOptions);
+		}
+	});
 	$('div.crumb:not(.last)').droppable(crumbDropOptions);
 	$('ul#apps>li:first-child').data('dir','');
 	if($('div.crumb').length){
@@ -56,7 +88,7 @@ $(document).ready(function() {
 
 	// Sets the file-action buttons behaviour :
 	$('tr').live('mouseenter',function(event) {
-		FileActions.display($(this).children('td.filename'), $(this).attr('data-file'), $(this).attr('data-type'));
+		FileActions.display($(this).children('td.filename'));
 	});
 	$('tr').live('mouseleave',function(event) {
 		FileActions.hide();
@@ -106,7 +138,8 @@ $(document).ready(function() {
 			if(!renaming && !FileList.isLoading(filename)){
 				var mime=$(this).parent().parent().data('mime');
 				var type=$(this).parent().parent().data('type');
-				var action=FileActions.getDefault(mime,type);
+				var permissions = $(this).parent().parent().data('permissions');
+				var action=FileActions.getDefault(mime,type, permissions);
 				if(action){
 					action(filename);
 				}
@@ -169,7 +202,12 @@ $(document).ready(function() {
 		var dir=$('#dir').val()||'/';
 		$('#notification').text(t('files','generating ZIP-file, it may take some time.'));
 		$('#notification').fadeIn();
-		window.location=OC.filePath('files', 'ajax', 'download.php') + '?'+ $.param({ dir: dir, files: files });
+		// use special download URL if provided, e.g. for public shared files
+		if ( (downloadURL = document.getElementById("downloadURL")) ) {
+			window.location=downloadURL.value+"&download&files="+files;
+		} else {
+			window.location=OC.filePath('files', 'ajax', 'download.php') + '?'+ $.param({ dir: dir, files: files });
+		}
 		return false;
 	});
 
@@ -186,6 +224,7 @@ $(document).ready(function() {
 			e.preventDefault(); // prevent browser from doing anything, if file isn't dropped in dropZone
 	});
 
+	if ( document.getElementById("data-upload-form") ) {
 	$(function() {
 		$('.file_upload_start').fileupload({
 			dropZone: $('#content'), // restrict dropZone to content div
@@ -194,6 +233,11 @@ $(document).ready(function() {
 				var totalSize=0;
 				if(files){
 					for(var i=0;i<files.length;i++){
+						if(files[i].size ==0 && files[i].type== '')
+						{
+							OC.dialogs.alert(t('files', 'Unable to upload your file as it is a directory or has 0 bytes'), t('files', 'Upload Error'));
+							return;
+						}
 						totalSize+=files[i].size;
 						if(FileList.deleteFiles && FileList.deleteFiles.indexOf(files[i].name)!=-1){//finish delete if we are uploading a deleted file
 							FileList.finishDelete(function(){
@@ -213,26 +257,99 @@ $(document).ready(function() {
 						}
 					});
 				}else{
-				if($.support.xhrFileUpload) {
-					for(var i=0;i<files.length;i++){
-						var fileName = files[i].name
-						var dropTarget = $(e.originalEvent.target).closest('tr');
-						if(dropTarget && dropTarget.attr('data-type') === 'dir') { // drag&drop upload to folder
-							var dirName = dropTarget.attr('data-file')
-							var jqXHR =  $('.file_upload_start').fileupload('send', {files: files[i],
-									formData: function(form) {
-										var formArray = form.serializeArray();
-										formArray[1]['value'] = dirName;
-										return formArray;
-									}}).success(function(result, textStatus, jqXHR) {
-										var response;
-										response=jQuery.parseJSON(result);
-										if(response[0] == undefined || response[0].status != 'success') {
-											$('#notification').text(t('files', response.data.message));
-											$('#notification').fadeIn();
-										}
-										var file=response[0];
-										delete uploadingFiles[dirName][file.name];
+					var dropTarget = $(e.originalEvent.target).closest('tr');
+					if(dropTarget && dropTarget.attr('data-type') === 'dir') { // drag&drop upload to folder
+						var dirName = dropTarget.attr('data-file')
+					}
+
+					var date=new Date();
+					if(files){
+						for(var i=0;i<files.length;i++){
+							if(files[i].size>0){
+								var size=files[i].size;
+							}else{
+								var size=t('files','Pending');
+							}
+							if(files && !dirName){
+								var uniqueName = getUniqueName(files[i].name);
+								if (uniqueName != files[i].name) {
+									FileList.checkName(uniqueName, files[i].name, true);
+									var hidden = true;
+								} else {
+									var hidden = false;
+								}
+								FileList.addFile(uniqueName,size,date,true,hidden);
+							} else if(dirName) {
+								var uploadtext = $('tr').filterAttr('data-type', 'dir').filterAttr('data-file', dirName).find('.uploadtext')
+								var currentUploads = parseInt(uploadtext.attr('currentUploads'));
+								currentUploads += 1;
+								uploadtext.attr('currentUploads', currentUploads);
+								if(currentUploads === 1) {
+									var img = OC.imagePath('core', 'loading.gif');
+									var tr=$('tr').filterAttr('data-file',dirName);
+									tr.find('td.filename').attr('style','background-image:url('+img+')');
+									uploadtext.text(t('files', '1 file uploading'));
+									uploadtext.show();
+								} else {
+									uploadtext.text(currentUploads + ' ' + t('files', 'files uploading'));
+								}
+							}
+						}
+					}else{
+						var filename=this.value.split('\\').pop(); //ie prepends C:\fakepath\ in front of the filename
+						var uniqueName = getUniqueName(filename);
+						if (uniqueName != filename) {
+							FileList.checkName(uniqueName, filename, true);
+							var hidden = true;
+						} else {
+							var hidden = false;
+						}
+						FileList.addFile(uniqueName,'Pending',date,true,hidden);
+					}
+					if($.support.xhrFileUpload) {
+						for(var i=0;i<files.length;i++){
+							var fileName = files[i].name
+							var dropTarget = $(e.originalEvent.target).closest('tr');
+							if(dropTarget && dropTarget.attr('data-type') === 'dir') { // drag&drop upload to folder
+								var dirName = dropTarget.attr('data-file')
+								var jqXHR =  $('.file_upload_start').fileupload('send', {files: files[i],
+										formData: function(form) {
+											var formArray = form.serializeArray();
+											// array index 0 contains the max files size
+											// array index 1 contains the request token
+											// array index 2 contains the directory
+											formArray[2]['value'] = dirName;
+											return formArray;
+										}}).success(function(result, textStatus, jqXHR) {
+											var response;
+											response=jQuery.parseJSON(result);
+											if(response[0] == undefined || response[0].status != 'success') {
+												$('#notification').text(t('files', response.data.message));
+												$('#notification').fadeIn();
+											}
+											var file=response[0];
+											// TODO: this doesn't work if the file name has been changed server side
+											delete uploadingFiles[dirName][file.name];
+											if ($.assocArraySize(uploadingFiles[dirName]) == 0) {
+												delete uploadingFiles[dirName];
+											}
+
+											var uploadtext = $('tr').filterAttr('data-type', 'dir').filterAttr('data-file', dirName).find('.uploadtext')
+											var currentUploads = parseInt(uploadtext.attr('currentUploads'));
+											currentUploads -= 1;
+											uploadtext.attr('currentUploads', currentUploads);
+											if(currentUploads === 0) {
+												var img = OC.imagePath('core', 'filetypes/folder.png');
+												var tr=$('tr').filterAttr('data-file',dirName);
+												tr.find('td.filename').attr('style','background-image:url('+img+')');
+												uploadtext.text('');
+												uploadtext.hide();
+											} else {
+												uploadtext.text(currentUploads + ' ' + t('files', 'files uploading'));
+											}
+										})
+								.error(function(jqXHR, textStatus, errorThrown) {
+									if(errorThrown === 'abort') {
 										var currentUploads = parseInt(uploadtext.attr('currentUploads'));
 										currentUploads -= 1;
 										uploadtext.attr('currentUploads', currentUploads);
@@ -243,114 +360,69 @@ $(document).ready(function() {
 											uploadtext.text('');
 											uploadtext.hide();
 										} else {
-											uploadtext.text(currentUploads + ' files uploading')
+											uploadtext.text(currentUploads + ' ' + t('files', 'files uploading'));
 										}
-									})
-							.error(function(jqXHR, textStatus, errorThrown) {
-								if(errorThrown === 'abort') {
-									var currentUploads = parseInt(uploadtext.attr('currentUploads'));
-									currentUploads -= 1;
-									uploadtext.attr('currentUploads', currentUploads);
-									if(currentUploads === 0) {
-										var img = OC.imagePath('core', 'filetypes/folder.png');
-										var tr=$('tr').filterAttr('data-file',dirName);
-										tr.find('td.filename').attr('style','background-image:url('+img+')');
-										uploadtext.text('');
-										uploadtext.hide();
-									} else {
-										uploadtext.text(currentUploads + ' files uploading')
+										$('#notification').hide();
+										$('#notification').text(t('files', 'Upload cancelled.'));
+										$('#notification').fadeIn();
 									}
-									$('#notification').hide();
-									$('#notification').text(t('files', 'Upload cancelled.'));
-									$('#notification').fadeIn();
+								});
+								//TODO test with filenames containing slashes
+								if(uploadingFiles[dirName] === undefined) {
+									uploadingFiles[dirName] = {};
 								}
-							});
-							//TODO test with filenames containing slashes
-							if(uploadingFiles[dirName] === undefined) {
-								uploadingFiles[dirName] = {};
-							}
-							uploadingFiles[dirName][fileName] = jqXHR;
-						} else {
-							var jqXHR =  $('.file_upload_start').fileupload('send', {files: files[i]})
-									.success(function(result, textStatus, jqXHR) {
-										var response;
-										response=jQuery.parseJSON(result);
-										if(response[0] != undefined && response[0].status == 'success') {
-											var file=response[0];
-											delete uploadingFiles[file.name];
-											$('tr').filterAttr('data-file',file.name).data('mime',file.mime);
-											var size = $('tr').filterAttr('data-file',file.name).find('td.filesize').text();
-											if(size==t('files','Pending')){
-												$('tr').filterAttr('data-file',file.name).find('td.filesize').text(file.size);
+								uploadingFiles[dirName][fileName] = jqXHR;
+							} else {
+								var jqXHR =  $('.file_upload_start').fileupload('send', {files: files[i]})
+										.success(function(result, textStatus, jqXHR) {
+											var response;
+											response=jQuery.parseJSON(result);
+											if(response[0] != undefined && response[0].status == 'success') {
+												var file=response[0];
+												delete uploadingFiles[file.name];
+												$('tr').filterAttr('data-file',file.name).data('mime',file.mime).data('id',file.id);
+												var size = $('tr').filterAttr('data-file',file.name).find('td.filesize').text();
+												if(size==t('files','Pending')){
+													$('tr').filterAttr('data-file',file.name).find('td.filesize').text(file.size);
+												}
+												FileList.loadingDone(file.name, file.id);
+											} else {
+												$('#notification').text(t('files', response.data.message));
+												$('#notification').fadeIn();
+												$('#fileList > tr').not('[data-mime]').fadeOut();
+												$('#fileList > tr').not('[data-mime]').remove();
 											}
-											FileList.loadingDone(file.name);
-										} else {
-											$('#notification').text(t('files', response.data.message));
-											$('#notification').fadeIn();
-											$('#fileList > tr').not('[data-mime]').fadeOut();
-											$('#fileList > tr').not('[data-mime]').remove();
-										}
-									})
-							.error(function(jqXHR, textStatus, errorThrown) {
-								if(errorThrown === 'abort') {
-									$('#notification').hide();
-									$('#notification').text(t('files', 'Upload cancelled.'));
-									$('#notification').fadeIn();
-								}
-							});
-							uploadingFiles[files[i].name] = jqXHR;
-						}
-					}
-				}else{
-					data.submit().success(function(data, status) {
-						response = jQuery.parseJSON(data[0].body.innerText);
-						if(response[0] != undefined && response[0].status == 'success') {
-							var file=response[0];
-							delete uploadingFiles[file.name];
-							$('tr').filterAttr('data-file',file.name).data('mime',file.mime);
-							var size = $('tr').filterAttr('data-file',file.name).find('td.filesize').text();
-							if(size==t('files','Pending')){
-								$('tr').filterAttr('data-file',file.name).find('td.filesize').text(file.size);
-							}
-							FileList.loadingDone(file.name);
-						} else {
-							$('#notification').text(t('files', response.data.message));
-							$('#notification').fadeIn();
-							$('#fileList > tr').not('[data-mime]').fadeOut();
-							$('#fileList > tr').not('[data-mime]').remove();
-						}
-					});
-				}
-									
-					var date=new Date();
-					if(files){
-						for(var i=0;i<files.length;i++){
-							if(files[i].size>0){
-								var size=files[i].size;
-							}else{
-								var size=t('files','Pending');
-							}
-							if(files && !dirName){
-						FileList.addFile(getUniqueName(files[i].name),size,date,true);
-							} else if(dirName) {
-								var uploadtext = $('tr').filterAttr('data-type', 'dir').filterAttr('data-file', dirName).find('.uploadtext')
-								var currentUploads = parseInt(uploadtext.attr('currentUploads'));
-								currentUploads += 1;
-								uploadtext.attr('currentUploads', currentUploads);
-								if(currentUploads === 1) {
-									var img = OC.imagePath('core', 'loading.gif');
-									var tr=$('tr').filterAttr('data-file',dirName);
-									tr.find('td.filename').attr('style','background-image:url('+img+')');
-									uploadtext.text('1 file uploading');
-									uploadtext.show();
-								} else {
-									uploadtext.text(currentUploads + ' files uploading')
-								}
+										})
+								.error(function(jqXHR, textStatus, errorThrown) {
+									if(errorThrown === 'abort') {
+										$('#notification').hide();
+										$('#notification').text(t('files', 'Upload cancelled.'));
+										$('#notification').fadeIn();
+									}
+								});
+								uploadingFiles[uniqueName] = jqXHR;
 							}
 						}
 					}else{
-						var filename=this.value.split('\\').pop(); //ie prepends C:\fakepath\ in front of the filename
-				FileList.addFile(getUniqueName(filename),'Pending',date,true);
+						data.submit().success(function(data, status) {
+							// in safari data is a string
+							response = jQuery.parseJSON(typeof data === 'string' ? data : data[0].body.innerText);
+							if(response[0] != undefined && response[0].status == 'success') {
+								var file=response[0];
+								delete uploadingFiles[file.name];
+								$('tr').filterAttr('data-file',file.name).data('mime',file.mime).data('id',file.id);
+								var size = $('tr').filterAttr('data-file',file.name).find('td.filesize').text();
+								if(size==t('files','Pending')){
+									$('tr').filterAttr('data-file',file.name).find('td.filesize').text(file.size);
+								}
+								FileList.loadingDone(file.name, file.id);
+							} else {
+								$('#notification').text(t('files', response.data.message));
+								$('#notification').fadeIn();
+								$('#fileList > tr').not('[data-mime]').fadeOut();
+								$('#fileList > tr').not('[data-mime]').remove();
+							}
+						});
 					}
 				}
 			},
@@ -374,12 +446,27 @@ $(document).ready(function() {
 			stop: function(e, data) {
 				if(data.dataType != 'iframe ') {
 					$('#upload input.stop').hide();
-				}	
+				}
 				$('#uploadprogressbar').progressbar('value',100);
 				$('#uploadprogressbar').fadeOut();
 			}
 		})
 	});
+	}
+	$.assocArraySize = function(obj) {
+		// http://stackoverflow.com/a/6700/11236
+		var size = 0, key;
+		for (key in obj) {
+			if (obj.hasOwnProperty(key)) size++;
+		}
+		return size;
+	};
+
+	// warn user not to leave the page while upload is in progress
+	$(window).bind('beforeunload', function(e) {
+		if ($.assocArraySize(uploadingFiles) > 0)
+			return t('files','File upload is in progress. Leaving the page now will cancel the upload.');
+	});
 
 	//add multiply file upload attribute to all browsers except konqueror (which crashes when it's used)
 	if(navigator.userAgent.search(/konqueror/i)==-1){
@@ -414,7 +501,7 @@ $(document).ready(function() {
 		$('button.file_upload_filename').removeClass('active');
 		$('#new li').each(function(i,element){
 			if($(element).children('p').length==0){
-				$(element).children('input').remove();
+				$(element).children('form').remove();
 				$(element).append('<p>'+$(element).data('text')+'</p>');
 			}
 		});
@@ -434,7 +521,7 @@ $(document).ready(function() {
 
 		$('#new li').each(function(i,element){
 			if($(element).children('p').length==0){
-				$(element).children('input').remove();
+				$(element).children('form').remove();
 				$(element).append('<p>'+$(element).data('text')+'</p>');
 			}
 		});
@@ -443,29 +530,51 @@ $(document).ready(function() {
 		var text=$(this).children('p').text();
 		$(this).data('text',text);
 		$(this).children('p').remove();
+		var form=$('<form></form>');
 		var input=$('<input>');
-		$(this).append(input);
+		form.append(input);
+		$(this).append(form);
 		input.focus();
-		input.change(function(){
-			var name=$(this).val();
-			if(type != 'web' && name.indexOf('/')!=-1){
-				$('#notification').text(t('files','Invalid name, \'/\' is not allowed.'));
+		form.submit(function(event){
+			event.stopPropagation();
+			event.preventDefault();
+			var newname=input.val();
+			if(type == 'web' && newname.length == 0){
+				$('#notification').text(t('files', "URL cannot be empty."));
 				$('#notification').fadeIn();
-				return;
+				return false;
+			} else if (type != 'web' && !Files.isFileNameValid(newname)) {
+				return false;
+			} else if( type == 'folder' && $('#dir').val() == '/' && newname == 'Shared') {
+				$('#notification').text(t('files','Invalid folder name. Usage of "Shared" is reserved by Owncloud'));
+				$('#notification').fadeIn();
+				return false;
+			}
+			var name = getUniqueName(newname);
+			if (newname != name) {
+				FileList.checkName(name, newname, true);
+				var hidden = true;
+			} else {
+				var hidden = false;
 			}
 			switch(type){
 				case 'file':
 					$.post(
 						OC.filePath('files','ajax','newfile.php'),
-						{dir:$('#dir').val(),filename:name,content:" \n"},
-						function(data){
-							var date=new Date();
-							FileList.addFile(name,0,date);
-							var tr=$('tr').filterAttr('data-file',name);
-							tr.data('mime','text/plain');
-							getMimeIcon('text/plain',function(path){
-								tr.find('td.filename').attr('style','background-image:url('+path+')');
-							});
+						{dir:$('#dir').val(),filename:name},
+						function(result){
+							if (result.status == 'success') {
+								var date=new Date();
+								FileList.addFile(name,0,date,false,hidden);
+								var tr=$('tr').filterAttr('data-file',name);
+								tr.data('mime','text/plain').data('id',result.data.id);
+								tr.attr('data-id', result.data.id);
+								getMimeIcon('text/plain',function(path){
+									tr.find('td.filename').attr('style','background-image:url('+path+')');
+								});
+							} else {
+								OC.dialogs.alert(result.data.message, 'Error');
+							}
 						}
 					);
 					break;
@@ -473,15 +582,21 @@ $(document).ready(function() {
 					$.post(
 						OC.filePath('files','ajax','newfolder.php'),
 						{dir:$('#dir').val(),foldername:name},
-						function(data){
-							var date=new Date();
-							FileList.addDir(name,0,date);
+						function(result){
+							if (result.status == 'success') {
+								var date=new Date();
+								FileList.addDir(name,0,date,hidden);
+								var tr=$('tr').filterAttr('data-file',name);
+								tr.attr('data-id', result.data.id);
+							} else {
+								OC.dialogs.alert(result.data.message, 'Error');
+							}
 						}
 					);
 					break;
 				case 'web':
 					if(name.substr(0,8)!='https://' && name.substr(0,7)!='http://'){
-						name='http://'.name;
+						name='http://'+name;
 					}
 					var localName=name;
 					if(localName.substr(localName.length-1,1)=='/'){//strip /
@@ -492,27 +607,36 @@ $(document).ready(function() {
 					}else{//or the domain
 						localName=(localName.match(/:\/\/(.[^/]+)/)[1]).replace('www.','');
 					}
-					$.post(
-						OC.filePath('files','ajax','newfile.php'),
-						{dir:$('#dir').val(),source:name,filename:localName},
-						function(result){
-							if(result.status == 'success'){
-								var date=new Date();
-								FileList.addFile(localName,0,date);
-								var tr=$('tr').filterAttr('data-file',localName);
-								tr.data('mime',result.data.mime);
-								getMimeIcon(result.data.mime,function(path){
-									tr.find('td.filename').attr('style','background-image:url('+path+')');
-								});
-							}else{
+					localName = getUniqueName(localName);
+					$('#uploadprogressbar').progressbar({value:0});
+					$('#uploadprogressbar').fadeIn();
 
-							}
-						}
-					);
+					var eventSource=new OC.EventSource(OC.filePath('files','ajax','newfile.php'),{dir:$('#dir').val(),source:name,filename:localName});
+					eventSource.listen('progress',function(progress){
+						$('#uploadprogressbar').progressbar('value',progress);
+					});
+					eventSource.listen('success',function(data){
+						var mime=data.mime;
+						var size=data.size;
+						var id=data.id;
+						$('#uploadprogressbar').fadeOut();
+						var date=new Date();
+						FileList.addFile(localName,size,date,false,hidden);
+						var tr=$('tr').filterAttr('data-file',localName);
+						tr.data('mime',mime).data('id',id);
+						tr.attr('data-id', id);
+						getMimeIcon(mime,function(path){
+							tr.find('td.filename').attr('style','background-image:url('+path+')');
+						});
+					});
+					eventSource.listen('error',function(error){
+						$('#uploadprogressbar').fadeOut();
+						alert(error);
+					});
 					break;
 			}
-			var li=$(this).parent();
-			$(this).remove();
+			var li=form.parent();
+			form.remove();
 			li.append('<p>'+li.data('text')+'</p>');
 			$('#new>a').click();
 		});
@@ -524,6 +648,72 @@ $(document).ready(function() {
 			scanFiles();
 		}
 	}, "json");
+
+	var lastWidth = 0;
+	var breadcrumbs = [];
+	var breadcrumbsWidth = 0;
+	if ( document.getElementById("navigation") ) {
+		breadcrumbsWidth = $('#navigation').get(0).offsetWidth;
+	}
+	var hiddenBreadcrumbs = 0;
+
+	$.each($('.crumb'), function(index, breadcrumb) {
+		breadcrumbs[index] = breadcrumb;
+		breadcrumbsWidth += $(breadcrumb).get(0).offsetWidth;
+	});
+
+	if ($('#controls .actions').length > 0) {
+		breadcrumbsWidth += $('#controls .actions').get(0).offsetWidth;
+	}
+
+	function resizeBreadcrumbs(firstRun) {
+		var width = $(this).width();
+		if (width != lastWidth) {
+			if ((width < lastWidth || firstRun) && width < breadcrumbsWidth) {
+				if (hiddenBreadcrumbs == 0) {
+					breadcrumbsWidth -= $(breadcrumbs[1]).get(0).offsetWidth;
+					$(breadcrumbs[1]).find('a').hide();
+					$(breadcrumbs[1]).append('<span>...</span>');
+					breadcrumbsWidth += $(breadcrumbs[1]).get(0).offsetWidth;
+					hiddenBreadcrumbs = 2;
+				}
+				var i = hiddenBreadcrumbs;
+				while (width < breadcrumbsWidth && i > 1 && i < breadcrumbs.length - 1) {
+					breadcrumbsWidth -= $(breadcrumbs[i]).get(0).offsetWidth;
+					$(breadcrumbs[i]).hide();
+					hiddenBreadcrumbs = i;
+					i++
+				}
+			} else if (width > lastWidth && hiddenBreadcrumbs > 0) {
+				var i = hiddenBreadcrumbs;
+				while (width > breadcrumbsWidth && i > 0) {
+					if (hiddenBreadcrumbs == 1) {
+						breadcrumbsWidth -= $(breadcrumbs[1]).get(0).offsetWidth;
+						$(breadcrumbs[1]).find('span').remove();
+						$(breadcrumbs[1]).find('a').show();
+						breadcrumbsWidth += $(breadcrumbs[1]).get(0).offsetWidth;
+					} else {
+						$(breadcrumbs[i]).show();
+						breadcrumbsWidth += $(breadcrumbs[i]).get(0).offsetWidth;
+						if (breadcrumbsWidth > width) {
+							breadcrumbsWidth -= $(breadcrumbs[i]).get(0).offsetWidth;
+							$(breadcrumbs[i]).hide();
+							break;
+						}
+					}
+					i--;
+					hiddenBreadcrumbs = i;
+				}
+			}
+			lastWidth = width;
+		}
+	}
+
+	$(window).resize(function() {
+		resizeBreadcrumbs(false);
+	});
+
+	resizeBreadcrumbs(true);
 });
 
 function scanFiles(force,dir){
@@ -537,7 +727,7 @@ function scanFiles(force,dir){
 	var scannerEventSource=new OC.EventSource(OC.filePath('files','ajax','scan.php'),{force:force,dir:dir});
 	scanFiles.cancel=scannerEventSource.close.bind(scannerEventSource);
 	scannerEventSource.listen('scanning',function(data){
-		$('#scan-count').text(data.count+' files scanned');
+		$('#scan-count').text(data.count + ' ' + t('files', 'files scanned'));
 		$('#scan-current').text(data.file+'/');
 	});
 	scannerEventSource.listen('success',function(success){
@@ -545,7 +735,7 @@ function scanFiles(force,dir){
 		if(success){
 			window.location.reload();
 		}else{
-			alert('error while scanning');
+			alert(t('files', 'error while scanning'));
 		}
 	});
 }
@@ -566,7 +756,7 @@ function updateBreadcrumb(breadcrumbHtml) {
 
 //options for file drag/dropp
 var dragOptions={
-	distance: 20, revert: 'invalid', opacity: 0.7,
+	distance: 20, revert: 'invalid', opacity: 0.7, helper: 'clone',
 	stop: function(event, ui) {
 		$('#fileList tr td.filename').addClass('ui-draggable');
 	}
@@ -685,7 +875,7 @@ function getSelectedFiles(property){
 			name:$(element).attr('data-file'),
 			mime:$(element).data('mime'),
 			type:$(element).data('type'),
-			size:$(element).data('size'),
+			size:$(element).data('size')
 		};
 		if(property){
 			files.push(file[property]);
@@ -701,28 +891,27 @@ function relative_modified_date(timestamp) {
 	var diffminutes = Math.round(timediff/60);
 	var diffhours = Math.round(diffminutes/60);
 	var diffdays = Math.round(diffhours/24);
-	var diffmonths = Math.round(diffdays/31);
-	var diffyears = Math.round(diffdays/365);
-	if(timediff < 60) { return t('files','seconds ago'); }
-	else if(timediff < 120) { return '1 '+t('files','minute ago'); }
-	else if(timediff < 3600) { return diffminutes+' '+t('files','minutes ago'); }
+	//var diffmonths = Math.round(diffdays/31);
+	//var diffyears = Math.round(diffdays/365);
+	if(timediff < 60) { return t('lib','seconds ago'); }
+	else if(timediff < 120) { return t('lib','1 minute ago'); }
+	else if(timediff < 3600) { return t('lib','%d minutes ago',diffminutes); }
 	//else if($timediff < 7200) { return '1 hour ago'; }
 	//else if($timediff < 86400) { return $diffhours.' hours ago'; }
-	else if(timediff < 86400) { return t('files','today'); }
-	else if(timediff < 172800) { return t('files','yesterday'); }
-	else if(timediff < 2678400) { return diffdays+' '+t('files','days ago'); }
-	else if(timediff < 5184000) { return t('files','last month'); }
-	//else if($timediff < 31556926) { return $diffmonths.' months ago'; }
-	else if(timediff < 31556926) { return t('files','months ago'); }
-	else if(timediff < 63113852) { return t('files','last year'); }
-	else { return diffyears+' '+t('files','years ago'); }
+	else if(timediff < 86400) { return t('lib','today'); }
+	else if(timediff < 172800) { return t('lib','yesterday'); }
+	else if(timediff < 2678400) { return t('lib','%d days ago',diffdays); }
+	else if(timediff < 5184000) { return t('lib','last month'); }
+	else if(timediff < 31556926) { return t('lib','months ago'); }
+	else if(timediff < 63113852) { return t('lib','last year'); }
+	else { return t('lib','years ago'); }
 }
 
 function getMimeIcon(mime, ready){
 	if(getMimeIcon.cache[mime]){
 		ready(getMimeIcon.cache[mime]);
 	}else{
-		$.get( OC.filePath('files','ajax','mimeicon.php')+'?mime='+mime, function(path){
+		$.get( OC.filePath('files','ajax','mimeicon.php'), {mime: mime}, function(path){
 			getMimeIcon.cache[mime]=path;
 			ready(getMimeIcon.cache[mime]);
 		});
@@ -733,7 +922,10 @@ getMimeIcon.cache={};
 function getUniqueName(name){
 	if($('tr').filterAttr('data-file',name).length>0){
 		var parts=name.split('.');
-		var extension=parts.pop();
+		var extension = "";
+		if (parts.length > 1) {
+			extension=parts.pop();
+		}
 		var base=parts.join('.');
 		numMatch=base.match(/\((\d+)\)/);
 		var num=2;
@@ -743,7 +935,10 @@ function getUniqueName(name){
 			base.pop();
 			base=base.join('(').trim();
 		}
-		name=base+' ('+num+').'+extension;
+		name=base+' ('+num+')';
+		if (extension) {
+			name = name+'.'+extension;
+		}
 		return getUniqueName(name);
 	}
 	return name;
