@@ -11,14 +11,14 @@ $(document).ready(function(){
 		onuncheck:blackListChange,
 		createText:'...',
 	});
-	
+
 	function blackListChange(){
 		var blackList=$('#encryption_blacklist').val().join(',');
 		OC.AppConfig.setValue('files_encryption','type_blacklist',blackList);
 	}
 
-	$('#enbale_encryption').change(function(){
-		var checked=$('#enbale_encryption').is(':checked');
+	$('#enable_encryption').change(function(){
+		var checked=$('#enable_encryption').is(':checked');
 		OC.AppConfig.setValue('files_encryption','enable_encryption',(checked)?'true':'false');
-	})
-})
\ No newline at end of file
+	});
+});
