@@ -1,8 +1,7 @@
 <?php
 
 OCP\JSON::checkAppEnabled('files_versions');
-
-require_once('apps/files_versions/versions.php');
+OCP\JSON::callCheck();
 
 $userDirectory = "/".OCP\USER::getUser()."/files";
 
@@ -10,7 +9,7 @@ $file = $_GET['file'];
 $revision=(int)$_GET['revision'];
 
 if( OCA_Versions\Storage::isversioned( $file ) ) {
-	if(OCA_Versions\Storage::rollback( $file, $revision )){
+	if(OCA_Versions\Storage::rollback( $file, $revision )) {
 		OCP\JSON::success(array("data" => array( "revision" => $revision, "file" => $file )));
 	}else{
 		OCP\JSON::error(array("data" => array( "message" => "Could not revert:" . $file )));
