@@ -1,5 +1,8 @@
 <?php $TRANSLATIONS = array(
 "Music" => "Música",
+"songs" => "canciones",
+"albums" => "álbumes",
+"Add album to playlist" => "Añadir un Album a la lista.",
 "Play" => "Reproducir",
 "Pause" => "Pausa",
 "Previous" => "Anterior",
