@@ -1,5 +1,8 @@
 <?php $TRANSLATIONS = array(
 "Music" => "ミュージック",
+"songs" => "曲",
+"albums" => "アルバム",
+"Add album to playlist" => "アルバムをプレイリストに追加",
 "Play" => "再生",
 "Pause" => "一時停止",
 "Previous" => "前",
