@@ -1,5 +1,8 @@
 <?php $TRANSLATIONS = array(
 "Music" => "Hudba",
+"songs" => "skladby",
+"albums" => "albumy",
+"Add album to playlist" => "Pridať album do playlistu",
 "Play" => "Prehrať",
 "Pause" => "Pauza",
 "Previous" => "Predchádzajúce",
