@@ -5,16 +5,18 @@
  * See the COPYING-README file.
  */
 
-require_once ("../../lib/base.php");
-OC_JSON::checkLoggedIn();
+require_once "../../lib/base.php";
+OC_Util::checkAdminUser();
+OCP\JSON::callCheck();
+
 $action=isset($_POST['action'])?$_POST['action']:$_GET['action'];
 $result=false;
-switch($action){
+switch($action) {
 	case 'getValue':
-		$result=OC_Appconfig::getValue($_GET['app'],$_GET['key'],$_GET['defaultValue']);
+		$result=OC_Appconfig::getValue($_GET['app'], $_GET['key'], $_GET['defaultValue']);
 		break;
 	case 'setValue':
-		$result=OC_Appconfig::setValue($_POST['app'],$_POST['key'],$_POST['value']);
+		$result=OC_Appconfig::setValue($_POST['app'], $_POST['key'], $_POST['value']);
 		break;
 	case 'getApps':
 		$result=OC_Appconfig::getApps();
@@ -23,10 +25,10 @@ switch($action){
 		$result=OC_Appconfig::getKeys($_GET['app']);
 		break;
 	case 'hasKey':
-		$result=OC_Appconfig::hasKey($_GET['app'],$_GET['key']);
+		$result=OC_Appconfig::hasKey($_GET['app'], $_GET['key']);
 		break;
 	case 'deleteKey':
-		$result=OC_Appconfig::deleteKey($_POST['app'],$_POST['key']);
+		$result=OC_Appconfig::deleteKey($_POST['app'], $_POST['key']);
 		break;
 	case 'deleteApp':
 		$result=OC_Appconfig::deleteApp($_POST['app']);
