@@ -1,4 +1,22 @@
 <?php $TRANSLATIONS = array(
+"Settings" => "Налаштування",
+"January" => "Січень",
+"February" => "Лютий",
+"March" => "Березень",
+"April" => "Квітень",
+"May" => "Травень",
+"June" => "Червень",
+"July" => "Липень",
+"August" => "Серпень",
+"September" => "Вересень",
+"October" => "Жовтень",
+"November" => "Листопад",
+"December" => "Грудень",
+"Cancel" => "Відмінити",
+"No" => "Ні",
+"Yes" => "Так",
+"Error" => "Помилка",
+"Password" => "Пароль",
 "You will receive a link to reset your password via Email." => "Ви отримаєте посилання для скидання вашого паролю на e-mail.",
 "Username" => "Ім'я користувача",
 "Your password was reset" => "Ваш пароль був скинутий",
@@ -9,7 +27,7 @@
 "Users" => "Користувачі",
 "Admin" => "Адміністратор",
 "Help" => "Допомога",
-"Password" => "Пароль",
+"Add" => "Додати",
 "Configure the database" => "Налаштування бази даних",
 "will be used" => "буде використано",
 "Database user" => "Користувач бази даних",
@@ -18,7 +36,6 @@
 "Finish setup" => "Завершити налаштування",
 "web services under your control" => "веб-сервіс під вашим контролем",
 "Log out" => "Вихід",
-"Settings" => "Налаштування",
 "Lost your password?" => "Забули пароль?",
 "remember" => "запам'ятати",
 "Log in" => "Вхід"
