@@ -1,5 +1,5 @@
 <?php
-if(!isset($_)){//also provide standalone error page
+if(!isset($_)) {//also provide standalone error page
 	require_once '../../lib/base.php';
 	
 	$tmpl = new OC_Template( '', '404', 'guest' );
@@ -10,6 +10,6 @@ if(!isset($_)){//also provide standalone error page
 <ul>
 	<li class='error'>
 		<?php echo $l->t( 'Cloud not found' ); ?><br/>
-		<p class='hint'><?php if(isset($_['file'])) echo htmlentities($_['file'])?></p>
+		<p class='hint'><?php if(isset($_['file'])) echo $_['file']?></p>
 	</li>
 </ul>
