@@ -1,20 +1,19 @@
 <?php
 
 // Init owncloud
-require_once('../../lib/base.php');
+require_once '../../lib/base.php';
 
 $l=OC_L10N::get('settings');
 
 OC_JSON::checkLoggedIn();
+OCP\JSON::callCheck();
 OC_JSON::checkAppEnabled('user_openid');
 
 // Get data
-if( isset( $_POST['identity'] ) ){
+if( isset( $_POST['identity'] ) ) {
 	$identity=$_POST['identity'];
-	OC_Preferences::setValue(OC_User::getUser(),'user_openid','identity',$identity);
+	OC_Preferences::setValue(OC_User::getUser(), 'user_openid', 'identity', $identity);
 	OC_JSON::success(array("data" => array( "message" => $l->t("OpenID Changed") )));
 }else{
 	OC_JSON::error(array("data" => array( "message" => $l->t("Invalid request") )));
 }
-
-?>
