@@ -5,11 +5,10 @@
  * See the COPYING-README file.
  */
 
-require_once('../../lib/base.php');
+require_once '../../lib/base.php';
 OC_Util::checkAdminUser();
+OCP\JSON::callCheck();
 
 OC_Config::setValue( 'loglevel', $_POST['level'] );
 
 echo 'true';
-
-?>
\ No newline at end of file
