@@ -7,14 +7,10 @@
 "More" => "Plus",
 "Add your App" => "Adder tu application",
 "Select an App" => "Selectionar un app",
-"by" => "per",
 "Documentation" => "Documentation",
 "Ask a question" => "Facer un question",
 "Answer" => "Responsa",
-"You use" => "Tu usa",
-"of the available" => "del disponibile",
 "Download" => "Discargar",
-"Your password got changed" => "Tu contrasigno esseva cambiate",
 "Unable to change your password" => "Non pote cambiar tu contrasigno",
 "Current password" => "Contrasigno currente",
 "New password" => "Nove contrasigno",
