@@ -3,15 +3,10 @@
 "Invalid request" => "Неисправан захтев",
 "Language changed" => "Језик је измењен",
 "Select an App" => "Изаберите програм",
-"-licensed" => "-лиценциран",
-"by" => "од",
 "Ask a question" => "Поставите питање",
 "Problems connecting to help database." => "Проблем у повезивању са базом помоћи",
 "Go there manually." => "Отиђите тамо ручно.",
 "Answer" => "Одговор",
-"You use" => "Користите",
-"of the available" => "од доступних",
-"Your password got changed" => "Ваша лозинка је измењена",
 "Unable to change your password" => "Не могу да изменим вашу лозинку",
 "Current password" => "Тренутна лозинка",
 "New password" => "Нова лозинка",
