@@ -3,15 +3,10 @@
 "Invalid request" => "Neispravan zahtev",
 "Language changed" => "Jezik je izmenjen",
 "Select an App" => "Izaberite program",
-"-licensed" => "-licenciran",
-"by" => "od",
 "Ask a question" => "Postavite pitanje",
 "Problems connecting to help database." => "Problem u povezivanju sa bazom pomoći",
 "Go there manually." => "Otiđite tamo ručno.",
 "Answer" => "Odgovor",
-"You use" => "Koristite",
-"of the available" => "od dostupnih",
-"Your password got changed" => "Vaša lozinka je izmenjena",
 "Unable to change your password" => "Ne mogu da izmenim vašu lozinku",
 "Current password" => "Trenutna lozinka",
 "New password" => "Nova lozinka",
