@@ -5,7 +5,7 @@
  * See the COPYING-README file.
  */
 
-require_once('../lib/base.php');
+require_once '../lib/base.php';
 OC_Util::checkLoggedIn();
 
 OC_Util::addStyle( 'settings', 'settings' );
@@ -13,8 +13,8 @@ OC_App::setActiveNavigationEntry( 'settings' );
 
 $tmpl = new OC_Template( 'settings', 'settings', 'user');
 $forms=OC_App::getForms('settings');
-$tmpl->assign('forms',array());
-foreach($forms as $form){
-	$tmpl->append('forms',$form);
+$tmpl->assign('forms', array());
+foreach($forms as $form) {
+	$tmpl->append('forms', $form);
 }
 $tmpl->printPage();
